 -----------------------------------------
    -- Bitmap images for various objects --
    -----------------------------------------

--   16 color graphics modes:

--   BLACK   = 0         GRAY           = 8
--   BLUE    = 1         BRIGHT_BLUE    = 9
--   GREEN   = 2         BRIGHT_GREEN   = A
--   CYAN    = 3         BRIGHT_CYAN    = B
--   RED     = C         BRIGHT_RED     = C
--   MAGENTA = 5         BRIGHT_MAGENTA = D
--   BROWN   = 6         YELLOW         = E
--   WHITE   = 9         BRIGHT_WHITE   = F

-- low order C bits determine the color seen by the user
-- 0: black part of outer space
-- 1..15: colored part of a solid object
-- 16..31: POD - solid, but phasors/torps can pass through it
-- 32: black part of a solid object
-- 33..6C: torpedos/phasors/explosion bits 
--         - ignorable fluff with no effect on the game
-- 65...: stars - no effect on game, but they shouldn't be destroyed



function make_image(sequence digits)
-- convert a 2-d sequence of hex digits into a 2-d image
    integer c
    
    for i = 1 to length(digits) do
	for j = 1 to length(digits[i]) do
	    c = digits[i][j] 
	    if c = ' ' then
		c = 32 -- BLACK (transparent) part of an object
	    elsif c >= 'A' then
		c -= 'A' - 10
	    else
		c -= '0'
	    end if
	    digits[i][j] = c
	end for
    end for
    return digits
end function

function flip_image(sequence digits)
-- make left-right mirror image
    for i = 1 to length(digits) do
	digits[i] = reverse(digits[i])
    end for
    return digits
end function

global constant SELECTED = make_image({
                                "FFFFFF00000000000FFFFFF",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
				"00000000000000000000000",
                                "00000000000000000000000",
                                "00000000000000000000000",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "F000000000000000000000F",
                                "FFFFFF00000000000FFFFFF"
                                            }),



STAR_DESTROYER = {{200,300},
                    make_image({"000000000090000000000",
                                "000000000090000000000",
                                "000000000090000000000",
                                "000000000999000000000",
                                "000000000999000000000",
                                "000000009999900000000",
                                "000000009999900000000",
                                "000000009999900000000",
                                "000000099999990000000",
                                "000000099999990000000",
                                "000000999999999000000",
                                "000000999999999000000",
                                "000009999999999900000",
                                "000009999999999900000",
                                "000009999999999900000",
                                "000099999999999990000",
				"000099999999999990000",
                                "000999999999999999000",
                                "000999999999999999000",
                                "009999999999999999900",
                                "009999999999999999900",
                                "099999999999999999990",
                                "099999999999999999990",
                                "999999999999999999999",
                                "999999999999999999999"
                                         })},
   
   
MON_CRUISER = {{100,300},
              make_image({
                          "0000CCCCC0000",
                          "000CCCCCCC000",
                          "00CCCCCCCCC00",
                          "00CCCCCCCCC00",
                          "0CCCCCCCCCCC0",
                          "0CCCCCCCCCCC0",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "CCCCCCCCCCCCC",
                          "0CCCCCCCCCCC0",
                          "0CCCCCCCCCCC0",
                          "00CCCCCCCCC00",
                          "000CCCCCCC000",
                          "0000CCCCC0000"
                             }),
              make_image({
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000",
                          "0000000000000"})}



display_image(STAR_DESTROYER[1],STAR_DESTROYER[2]) 
display_image(MON_CRUISER[1],MON_CRUISER[2]) 